Class: Google::Cloud::ConfidentialComputing::V1::VerifyConfidentialGkeResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/confidentialcomputing/v1/service.rb

Overview

VerifyConfidentialGkeResponse response is returened once a Confidential GKE attestation has been successfully verified, containing a signed OIDC token.

Instance Attribute Summary collapse

Instance Attribute Details

#attestation_token::String (readonly)

Returns Output only. The attestation token issued by this service for Confidential GKE. It contains specific platform claims based on the contents of the provided attestation.

Returns:

  • (::String)

    Output only. The attestation token issued by this service for Confidential GKE. It contains specific platform claims based on the contents of the provided attestation.



590
591
592
593
# File 'proto_docs/google/cloud/confidentialcomputing/v1/service.rb', line 590

class VerifyConfidentialGkeResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end