Class: Google::Cloud::ConfidentialComputing::V1::VerifyConfidentialSpaceRequest::ConfidentialSpaceOptions

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/confidentialcomputing/v1/service.rb

Overview

Token options for Confidential Space attestation.

Instance Attribute Summary collapse

Instance Attribute Details

#audience::String

Returns Optional. Optional string to issue the token with a custom audience claim. Required if custom nonces are specified.

Returns:

  • (::String)

    Optional. Optional string to issue the token with a custom audience claim. Required if custom nonces are specified.



504
505
506
507
# File 'proto_docs/google/cloud/confidentialcomputing/v1/service.rb', line 504

class ConfidentialSpaceOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#aws_principal_tags_options::Google::Cloud::ConfidentialComputing::V1::AwsPrincipalTagsOptions

Returns Optional. Options for the AWS token type.

Returns:



504
505
506
507
# File 'proto_docs/google/cloud/confidentialcomputing/v1/service.rb', line 504

class ConfidentialSpaceOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#nonce::Array<::String>

Returns Optional. Optional parameter to place one or more nonces in the eat_nonce claim in the output token. The minimum size for JSON-encoded EATs is 10 bytes and the maximum size is 74 bytes.

Returns:

  • (::Array<::String>)

    Optional. Optional parameter to place one or more nonces in the eat_nonce claim in the output token. The minimum size for JSON-encoded EATs is 10 bytes and the maximum size is 74 bytes.



504
505
506
507
# File 'proto_docs/google/cloud/confidentialcomputing/v1/service.rb', line 504

class ConfidentialSpaceOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#signature_type::Google::Cloud::ConfidentialComputing::V1::SignatureType

Returns Optional. Optional specification for how to sign the attestation token. Defaults to SIGNATURE_TYPE_OIDC if unspecified.

Returns:



504
505
506
507
# File 'proto_docs/google/cloud/confidentialcomputing/v1/service.rb', line 504

class ConfidentialSpaceOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#token_profile::Google::Cloud::ConfidentialComputing::V1::TokenProfile

Returns Optional. Optional specification for token claims profile.

Returns:



504
505
506
507
# File 'proto_docs/google/cloud/confidentialcomputing/v1/service.rb', line 504

class ConfidentialSpaceOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end