Class: Google::Cloud::ConfidentialComputing::V1::VerifyConfidentialSpaceResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/confidentialcomputing/v1/service.rb

Overview

VerifyConfidentialSpaceResponse is returned once a Confidential Space attestation has been successfully verified, containing a signed token.

Instance Attribute Summary collapse

Instance Attribute Details

#attestation_token::String (readonly)

Returns Output only. The attestation token issued by this service. It contains specific platform claims based on the contents of the provided attestation.

Returns:

  • (::String)

    Output only. The attestation token issued by this service. It contains specific platform claims based on the contents of the provided attestation.



539
540
541
542
# File 'proto_docs/google/cloud/confidentialcomputing/v1/service.rb', line 539

class VerifyConfidentialSpaceResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#partial_errors::Array<::Google::Rpc::Status> (readonly)

Returns Output only. A list of messages that carry the partial error details related to VerifyConfidentialSpace. This field is populated by errors during container image signature verification, which may reflect problems in the provided image signatures. This does not block the issuing of an attestation token, but the token will not contain claims for the failed image signatures.

Returns:

  • (::Array<::Google::Rpc::Status>)

    Output only. A list of messages that carry the partial error details related to VerifyConfidentialSpace. This field is populated by errors during container image signature verification, which may reflect problems in the provided image signatures. This does not block the issuing of an attestation token, but the token will not contain claims for the failed image signatures.



539
540
541
542
# File 'proto_docs/google/cloud/confidentialcomputing/v1/service.rb', line 539

class VerifyConfidentialSpaceResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end