Class: Google::Cloud::ConfidentialComputing::V1::NvidiaAttestation
- Inherits:
-
Object
- Object
- Google::Cloud::ConfidentialComputing::V1::NvidiaAttestation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/confidentialcomputing/v1/service.rb
Overview
An Nvidia attestation report for GPU and NVSwitch devices. Contains necessary attestation evidence that the client collects for verification.
Defined Under Namespace
Modules: GpuArchitectureType Classes: GpuInfo, MultiGpuSecurePassthroughAttestation, ProtectedPcieAttestation, SinglePassthroughAttestation, SwitchInfo
Instance Attribute Summary collapse
-
#mpt ⇒ ::Google::Cloud::ConfidentialComputing::V1::NvidiaAttestation::MultiGpuSecurePassthroughAttestation
Multi-GPU Secure Passthrough (MPT) attestation.
-
#ppcie ⇒ ::Google::Cloud::ConfidentialComputing::V1::NvidiaAttestation::ProtectedPcieAttestation
Protected PCIe (PPCIE) attestation.
-
#spt ⇒ ::Google::Cloud::ConfidentialComputing::V1::NvidiaAttestation::SinglePassthroughAttestation
Single GPU Passthrough (SPT) attestation.
Instance Attribute Details
#mpt ⇒ ::Google::Cloud::ConfidentialComputing::V1::NvidiaAttestation::MultiGpuSecurePassthroughAttestation
Returns Multi-GPU Secure Passthrough (MPT) attestation.
Note: The following fields are mutually exclusive: mpt, spt, ppcie. If a field in that set is populated, all other fields in the set will automatically be cleared.
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'proto_docs/google/cloud/confidentialcomputing/v1/service.rb', line 128 class NvidiaAttestation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # GpuInfo contains the attestation evidence for a GPU device. # @!attribute [rw] uuid # @return [::String] # Optional. The UUID of the GPU device. # @!attribute [rw] driver_version # @return [::String] # Optional. The driver version of the GPU. # @!attribute [rw] vbios_version # @return [::String] # Optional. The vBIOS version of the GPU. # @!attribute [rw] gpu_architecture_type # @return [::Google::Cloud::ConfidentialComputing::V1::NvidiaAttestation::GpuArchitectureType] # Optional. The GPU architecture type. # @!attribute [rw] attestation_certificate_chain # @return [::String] # Optional. The raw attestation certificate chain for the GPU device. # @!attribute [rw] attestation_report # @return [::String] # Optional. The raw attestation report for the GPU device. # This field contains SPDM request/response defined in # https://www.dmtf.org/sites/default/files/standards/documents/DSP0274_1.1.0.pdf class GpuInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # SwitchInfo contains the attestation evidence for a NVSwitch device. # @!attribute [rw] uuid # @return [::String] # Optional. The UUID of the NVSwitch device. # @!attribute [rw] attestation_certificate_chain # @return [::String] # Optional. The raw attestation certificate chain for the NVSwitch device. # @!attribute [rw] attestation_report # @return [::String] # Optional. The raw attestation report for the NvSwitch device. # This field contains SPDM request/response defined in # https://www.dmtf.org/sites/default/files/standards/documents/DSP0274_1.1.0.pdf class SwitchInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Single GPU Passthrough (SPT) attestation. # @!attribute [rw] gpu_quote # @return [::Google::Cloud::ConfidentialComputing::V1::NvidiaAttestation::GpuInfo] # Optional. Single GPU quote. class SinglePassthroughAttestation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Protected PCIe (PPCIE) attestation. # Eight Hopper GPUs with Four NVSwitch Passthrough. # @!attribute [rw] gpu_quotes # @return [::Array<::Google::Cloud::ConfidentialComputing::V1::NvidiaAttestation::GpuInfo>] # Optional. A list of GPU infos. # @!attribute [rw] switch_quotes # @return [::Array<::Google::Cloud::ConfidentialComputing::V1::NvidiaAttestation::SwitchInfo>] # Optional. A list of SWITCH infos. class ProtectedPcieAttestation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # MultiGpuSecurePassthroughAttestation contains the attestation evidence # for a Multi-GPU Secure Passthrough (MPT) attestation. # @!attribute [rw] gpu_quotes # @return [::Array<::Google::Cloud::ConfidentialComputing::V1::NvidiaAttestation::GpuInfo>] # Optional. A list of GPU quotes. class MultiGpuSecurePassthroughAttestation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # GpuArchitectureType enumerates the supported GPU architecture types. module GpuArchitectureType # Unspecified GPU architecture type. GPU_ARCHITECTURE_TYPE_UNSPECIFIED = 0 # Hopper GPU architecture type. GPU_ARCHITECTURE_TYPE_HOPPER = 8 # Blackwell GPU architecture type. GPU_ARCHITECTURE_TYPE_BLACKWELL = 10 end end |
#ppcie ⇒ ::Google::Cloud::ConfidentialComputing::V1::NvidiaAttestation::ProtectedPcieAttestation
Returns Protected PCIe (PPCIE) attestation.
Note: The following fields are mutually exclusive: ppcie, spt, mpt. If a field in that set is populated, all other fields in the set will automatically be cleared.
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'proto_docs/google/cloud/confidentialcomputing/v1/service.rb', line 128 class NvidiaAttestation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # GpuInfo contains the attestation evidence for a GPU device. # @!attribute [rw] uuid # @return [::String] # Optional. The UUID of the GPU device. # @!attribute [rw] driver_version # @return [::String] # Optional. The driver version of the GPU. # @!attribute [rw] vbios_version # @return [::String] # Optional. The vBIOS version of the GPU. # @!attribute [rw] gpu_architecture_type # @return [::Google::Cloud::ConfidentialComputing::V1::NvidiaAttestation::GpuArchitectureType] # Optional. The GPU architecture type. # @!attribute [rw] attestation_certificate_chain # @return [::String] # Optional. The raw attestation certificate chain for the GPU device. # @!attribute [rw] attestation_report # @return [::String] # Optional. The raw attestation report for the GPU device. # This field contains SPDM request/response defined in # https://www.dmtf.org/sites/default/files/standards/documents/DSP0274_1.1.0.pdf class GpuInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # SwitchInfo contains the attestation evidence for a NVSwitch device. # @!attribute [rw] uuid # @return [::String] # Optional. The UUID of the NVSwitch device. # @!attribute [rw] attestation_certificate_chain # @return [::String] # Optional. The raw attestation certificate chain for the NVSwitch device. # @!attribute [rw] attestation_report # @return [::String] # Optional. The raw attestation report for the NvSwitch device. # This field contains SPDM request/response defined in # https://www.dmtf.org/sites/default/files/standards/documents/DSP0274_1.1.0.pdf class SwitchInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Single GPU Passthrough (SPT) attestation. # @!attribute [rw] gpu_quote # @return [::Google::Cloud::ConfidentialComputing::V1::NvidiaAttestation::GpuInfo] # Optional. Single GPU quote. class SinglePassthroughAttestation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Protected PCIe (PPCIE) attestation. # Eight Hopper GPUs with Four NVSwitch Passthrough. # @!attribute [rw] gpu_quotes # @return [::Array<::Google::Cloud::ConfidentialComputing::V1::NvidiaAttestation::GpuInfo>] # Optional. A list of GPU infos. # @!attribute [rw] switch_quotes # @return [::Array<::Google::Cloud::ConfidentialComputing::V1::NvidiaAttestation::SwitchInfo>] # Optional. A list of SWITCH infos. class ProtectedPcieAttestation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # MultiGpuSecurePassthroughAttestation contains the attestation evidence # for a Multi-GPU Secure Passthrough (MPT) attestation. # @!attribute [rw] gpu_quotes # @return [::Array<::Google::Cloud::ConfidentialComputing::V1::NvidiaAttestation::GpuInfo>] # Optional. A list of GPU quotes. class MultiGpuSecurePassthroughAttestation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # GpuArchitectureType enumerates the supported GPU architecture types. module GpuArchitectureType # Unspecified GPU architecture type. GPU_ARCHITECTURE_TYPE_UNSPECIFIED = 0 # Hopper GPU architecture type. GPU_ARCHITECTURE_TYPE_HOPPER = 8 # Blackwell GPU architecture type. GPU_ARCHITECTURE_TYPE_BLACKWELL = 10 end end |
#spt ⇒ ::Google::Cloud::ConfidentialComputing::V1::NvidiaAttestation::SinglePassthroughAttestation
Returns Single GPU Passthrough (SPT) attestation.
Note: The following fields are mutually exclusive: spt, ppcie, mpt. If a field in that set is populated, all other fields in the set will automatically be cleared.
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'proto_docs/google/cloud/confidentialcomputing/v1/service.rb', line 128 class NvidiaAttestation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # GpuInfo contains the attestation evidence for a GPU device. # @!attribute [rw] uuid # @return [::String] # Optional. The UUID of the GPU device. # @!attribute [rw] driver_version # @return [::String] # Optional. The driver version of the GPU. # @!attribute [rw] vbios_version # @return [::String] # Optional. The vBIOS version of the GPU. # @!attribute [rw] gpu_architecture_type # @return [::Google::Cloud::ConfidentialComputing::V1::NvidiaAttestation::GpuArchitectureType] # Optional. The GPU architecture type. # @!attribute [rw] attestation_certificate_chain # @return [::String] # Optional. The raw attestation certificate chain for the GPU device. # @!attribute [rw] attestation_report # @return [::String] # Optional. The raw attestation report for the GPU device. # This field contains SPDM request/response defined in # https://www.dmtf.org/sites/default/files/standards/documents/DSP0274_1.1.0.pdf class GpuInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # SwitchInfo contains the attestation evidence for a NVSwitch device. # @!attribute [rw] uuid # @return [::String] # Optional. The UUID of the NVSwitch device. # @!attribute [rw] attestation_certificate_chain # @return [::String] # Optional. The raw attestation certificate chain for the NVSwitch device. # @!attribute [rw] attestation_report # @return [::String] # Optional. The raw attestation report for the NvSwitch device. # This field contains SPDM request/response defined in # https://www.dmtf.org/sites/default/files/standards/documents/DSP0274_1.1.0.pdf class SwitchInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Single GPU Passthrough (SPT) attestation. # @!attribute [rw] gpu_quote # @return [::Google::Cloud::ConfidentialComputing::V1::NvidiaAttestation::GpuInfo] # Optional. Single GPU quote. class SinglePassthroughAttestation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Protected PCIe (PPCIE) attestation. # Eight Hopper GPUs with Four NVSwitch Passthrough. # @!attribute [rw] gpu_quotes # @return [::Array<::Google::Cloud::ConfidentialComputing::V1::NvidiaAttestation::GpuInfo>] # Optional. A list of GPU infos. # @!attribute [rw] switch_quotes # @return [::Array<::Google::Cloud::ConfidentialComputing::V1::NvidiaAttestation::SwitchInfo>] # Optional. A list of SWITCH infos. class ProtectedPcieAttestation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # MultiGpuSecurePassthroughAttestation contains the attestation evidence # for a Multi-GPU Secure Passthrough (MPT) attestation. # @!attribute [rw] gpu_quotes # @return [::Array<::Google::Cloud::ConfidentialComputing::V1::NvidiaAttestation::GpuInfo>] # Optional. A list of GPU quotes. class MultiGpuSecurePassthroughAttestation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # GpuArchitectureType enumerates the supported GPU architecture types. module GpuArchitectureType # Unspecified GPU architecture type. GPU_ARCHITECTURE_TYPE_UNSPECIFIED = 0 # Hopper GPU architecture type. GPU_ARCHITECTURE_TYPE_HOPPER = 8 # Blackwell GPU architecture type. GPU_ARCHITECTURE_TYPE_BLACKWELL = 10 end end |