Class: Google::Cloud::ConfidentialComputing::V1::VerifyAttestationRequest
- Inherits:
-
Object
- Object
- Google::Cloud::ConfidentialComputing::V1::VerifyAttestationRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/confidentialcomputing/v1/service.rb
Overview
A request for an attestation token, providing all the necessary information needed for this service to verify the platform state of the requestor.
Instance Attribute Summary collapse
-
#attester ⇒ ::String
Optional.
-
#challenge ⇒ ::String
Required.
-
#confidential_space_info ⇒ ::Google::Cloud::ConfidentialComputing::V1::ConfidentialSpaceInfo
Optional.
-
#gcp_credentials ⇒ ::Google::Cloud::ConfidentialComputing::V1::GcpCredentials
Optional.
-
#instance ⇒ ::String
Optional.
-
#nvidia_attestation ⇒ ::Google::Cloud::ConfidentialComputing::V1::NvidiaAttestation
Optional.
-
#sev_snp_attestation ⇒ ::Google::Cloud::ConfidentialComputing::V1::SevSnpAttestation
Optional.
-
#td_ccel ⇒ ::Google::Cloud::ConfidentialComputing::V1::TdxCcelAttestation
Optional.
-
#token_options ⇒ ::Google::Cloud::ConfidentialComputing::V1::TokenOptions
Optional.
-
#tpm_attestation ⇒ ::Google::Cloud::ConfidentialComputing::V1::TpmAttestation
Required.
Instance Attribute Details
#attester ⇒ ::String
Returns Optional. An optional indicator of the attester, only applies to certain products.
105 106 107 108 |
# File 'proto_docs/google/cloud/confidentialcomputing/v1/service.rb', line 105 class VerifyAttestationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#challenge ⇒ ::String
Returns Required. The name of the Challenge whose nonce was used to generate the
attestation, in the format projects/*/locations/*/challenges/*. The
provided Challenge will be consumed, and cannot be used again.
105 106 107 108 |
# File 'proto_docs/google/cloud/confidentialcomputing/v1/service.rb', line 105 class VerifyAttestationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#confidential_space_info ⇒ ::Google::Cloud::ConfidentialComputing::V1::ConfidentialSpaceInfo
Returns Optional. Optional information related to the Confidential Space TEE.
105 106 107 108 |
# File 'proto_docs/google/cloud/confidentialcomputing/v1/service.rb', line 105 class VerifyAttestationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#gcp_credentials ⇒ ::Google::Cloud::ConfidentialComputing::V1::GcpCredentials
Returns Optional. Credentials used to populate the "emails" claim in the claims_token.
105 106 107 108 |
# File 'proto_docs/google/cloud/confidentialcomputing/v1/service.rb', line 105 class VerifyAttestationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#instance ⇒ ::String
Returns Optional. Optional resource link of the Compute Engine instance.
Format:
projects/{project_number}/zones/{zone}/instances/{instance_id}.
105 106 107 108 |
# File 'proto_docs/google/cloud/confidentialcomputing/v1/service.rb', line 105 class VerifyAttestationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#nvidia_attestation ⇒ ::Google::Cloud::ConfidentialComputing::V1::NvidiaAttestation
Returns Optional. An Nvidia attestation report for GPU and NVSwitch devices.
105 106 107 108 |
# File 'proto_docs/google/cloud/confidentialcomputing/v1/service.rb', line 105 class VerifyAttestationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#sev_snp_attestation ⇒ ::Google::Cloud::ConfidentialComputing::V1::SevSnpAttestation
Returns Optional. An SEV-SNP Attestation Report.
Note: The following fields are mutually exclusive: sev_snp_attestation, td_ccel. If a field in that set is populated, all other fields in the set will automatically be cleared.
105 106 107 108 |
# File 'proto_docs/google/cloud/confidentialcomputing/v1/service.rb', line 105 class VerifyAttestationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#td_ccel ⇒ ::Google::Cloud::ConfidentialComputing::V1::TdxCcelAttestation
Returns Optional. A TDX with CCEL and RTMR Attestation Quote.
Note: The following fields are mutually exclusive: td_ccel, sev_snp_attestation. If a field in that set is populated, all other fields in the set will automatically be cleared.
105 106 107 108 |
# File 'proto_docs/google/cloud/confidentialcomputing/v1/service.rb', line 105 class VerifyAttestationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#token_options ⇒ ::Google::Cloud::ConfidentialComputing::V1::TokenOptions
Returns Optional. A collection of optional, workload-specified claims that modify the token output.
105 106 107 108 |
# File 'proto_docs/google/cloud/confidentialcomputing/v1/service.rb', line 105 class VerifyAttestationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#tpm_attestation ⇒ ::Google::Cloud::ConfidentialComputing::V1::TpmAttestation
Returns Required. The TPM-specific data provided by the attesting platform, used to populate any of the claims regarding platform state.
105 106 107 108 |
# File 'proto_docs/google/cloud/confidentialcomputing/v1/service.rb', line 105 class VerifyAttestationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |