Class: Google::Cloud::ConfidentialComputing::V1::VerifyConfidentialGkeRequest
- Inherits:
-
Object
- Object
- Google::Cloud::ConfidentialComputing::V1::VerifyConfidentialGkeRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/confidentialcomputing/v1/service.rb
Overview
A request for an attestation token, providing all the necessary information needed for this service to verify Confidential GKE platform state of the requestor.
Defined Under Namespace
Classes: ConfidentialGkeOptions
Instance Attribute Summary collapse
-
#challenge ⇒ ::String
Required.
-
#options ⇒ ::Google::Cloud::ConfidentialComputing::V1::VerifyConfidentialGkeRequest::ConfidentialGkeOptions
Optional.
-
#tpm_attestation ⇒ ::Google::Cloud::ConfidentialComputing::V1::TpmAttestation
The TPM-specific data provided by the attesting platform, used to populate any of the claims regarding platform state.
Instance Attribute Details
#challenge ⇒ ::String
Returns Required. The name of the Challenge whose nonce was used to generate the attestation, in the format projects//locations//challenges/*. The provided Challenge will be consumed, and cannot be used again.
559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 |
# File 'proto_docs/google/cloud/confidentialcomputing/v1/service.rb', line 559 class VerifyConfidentialGkeRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Token options for Confidential GKE attestation. # @!attribute [rw] audience # @return [::String] # Optional. Optional string to issue the token with a custom audience # claim. Required if custom nonces are specified. # @!attribute [rw] nonce # @return [::Array<::String>] # Optional. Optional parameter to place one or more nonces in the eat_nonce # claim in the output token. The minimum size for JSON-encoded EATs is 10 # bytes and the maximum size is 74 bytes. # @!attribute [rw] signature_type # @return [::Google::Cloud::ConfidentialComputing::V1::SignatureType] # Optional. Optional specification for how to sign the attestation token. # Defaults to SIGNATURE_TYPE_OIDC if unspecified. class ConfidentialGkeOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#options ⇒ ::Google::Cloud::ConfidentialComputing::V1::VerifyConfidentialGkeRequest::ConfidentialGkeOptions
Returns Optional. A collection of fields that modify the token output.
559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 |
# File 'proto_docs/google/cloud/confidentialcomputing/v1/service.rb', line 559 class VerifyConfidentialGkeRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Token options for Confidential GKE attestation. # @!attribute [rw] audience # @return [::String] # Optional. Optional string to issue the token with a custom audience # claim. Required if custom nonces are specified. # @!attribute [rw] nonce # @return [::Array<::String>] # Optional. Optional parameter to place one or more nonces in the eat_nonce # claim in the output token. The minimum size for JSON-encoded EATs is 10 # bytes and the maximum size is 74 bytes. # @!attribute [rw] signature_type # @return [::Google::Cloud::ConfidentialComputing::V1::SignatureType] # Optional. Optional specification for how to sign the attestation token. # Defaults to SIGNATURE_TYPE_OIDC if unspecified. class ConfidentialGkeOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#tpm_attestation ⇒ ::Google::Cloud::ConfidentialComputing::V1::TpmAttestation
Returns The TPM-specific data provided by the attesting platform, used to populate any of the claims regarding platform state.
559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 |
# File 'proto_docs/google/cloud/confidentialcomputing/v1/service.rb', line 559 class VerifyConfidentialGkeRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Token options for Confidential GKE attestation. # @!attribute [rw] audience # @return [::String] # Optional. Optional string to issue the token with a custom audience # claim. Required if custom nonces are specified. # @!attribute [rw] nonce # @return [::Array<::String>] # Optional. Optional parameter to place one or more nonces in the eat_nonce # claim in the output token. The minimum size for JSON-encoded EATs is 10 # bytes and the maximum size is 74 bytes. # @!attribute [rw] signature_type # @return [::Google::Cloud::ConfidentialComputing::V1::SignatureType] # Optional. Optional specification for how to sign the attestation token. # Defaults to SIGNATURE_TYPE_OIDC if unspecified. class ConfidentialGkeOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |