Class: Google::Cloud::ConfidentialComputing::V1::VerifyConfidentialGkeRequest::ConfidentialGkeOptions
- Inherits:
-
Object
- Object
- Google::Cloud::ConfidentialComputing::V1::VerifyConfidentialGkeRequest::ConfidentialGkeOptions
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/confidentialcomputing/v1/service.rb
Overview
Token options for Confidential GKE attestation.
Instance Attribute Summary collapse
-
#audience ⇒ ::String
Optional.
-
#nonce ⇒ ::Array<::String>
Optional.
-
#signature_type ⇒ ::Google::Cloud::ConfidentialComputing::V1::SignatureType
Optional.
Instance Attribute Details
#audience ⇒ ::String
Returns Optional. Optional string to issue the token with a custom audience claim. Required if custom nonces are specified.
577 578 579 580 |
# File 'proto_docs/google/cloud/confidentialcomputing/v1/service.rb', line 577 class ConfidentialGkeOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#nonce ⇒ ::Array<::String>
Returns Optional. Optional parameter to place one or more nonces in the eat_nonce claim in the output token. The minimum size for JSON-encoded EATs is 10 bytes and the maximum size is 74 bytes.
577 578 579 580 |
# File 'proto_docs/google/cloud/confidentialcomputing/v1/service.rb', line 577 class ConfidentialGkeOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#signature_type ⇒ ::Google::Cloud::ConfidentialComputing::V1::SignatureType
Returns Optional. Optional specification for how to sign the attestation token. Defaults to SIGNATURE_TYPE_OIDC if unspecified.
577 578 579 580 |
# File 'proto_docs/google/cloud/confidentialcomputing/v1/service.rb', line 577 class ConfidentialGkeOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |